==> DownloadManager-1.4.1.zip: DownloadManager/action.selector.php <==
<?php
if (!isset($gCms)) exit;
//var_dump($params);

/*
 * PARSING selector
 *
 * Here come everything what has to do with selector,
 * if selector parameter is set the other parameters
 * are omnited
*/

if( !isset( $params['selector'] ) )
	echo $this->DisplayErrorPage($id, $params, $returnid, $this->lang('nocategorysel'));

$showheaders = false;
// parsing the category selector
$categoryid  = html_entity_decode( $params['selector'] );
$pattern = '/([^0-9()|&])+/i';
$categoryclean = $categoryid  = preg_replace($pattern, '', $categoryid); // cleaning
//	var_dump($categoryid);

$arr = array(); // array for storing pairs

$this->MatchPair( $categoryid , $arr); // recursive category selector parsing

$categoryid = str_replace( array("(",")"), '' , $categoryid);
if ( preg_match('/^[$]?\d+$/i', $categoryid) == 0 )
{
	$this->DisplayErrorPage($id, $params, $returnid, $this->lang('wrongcategorysel', $categoryclean) );
	return;
}

// not we are sure that category selector is ok
// we can change it to sql

$sql_prefix = 'SELECT file_id FROM '.cms_db_prefix().'module_downloadmanager_files WHERE '.$this->GetFileStdWhere().' AND ';
$sql = '';

foreach( $arr as $k => $v )
{
	$tmp = array();
	if( is_null($v) )
		continue;

	$v = array_unique($v); // no need for doubles

	$op = $v[0]; // get operator
	unset($v[0]);  // clean operator

	foreach($v as $tv)
	{
		if($tv{0} == '$') // we get a referal
		{
			$z = (int) substr($tv, 1);
			$tmp[] = $arr[$z];
		}
		else
			$tmp[] = 'hierarchy LIKE \'%'.str_pad($tv, 5, '0', STR_PAD_LEFT).'%\'';
	}

	if( $op == '|' )
		$op = " OR ";
	else
		$op = " AND ";

	$sql = $arr[$k] = "(".implode($op, $tmp).")";

}

$sql = $sql_prefix. $sql;
$query = 'SELECT * FROM '.cms_db_prefix().'module_downloadmanager_files
		WHERE file_id IN ('.$sql.")
		ORDER BY name";
$files_categories = $this->GetFileCategories('file_id IN ('.$sql.')');

$dbresult = $db->Execute($query);

// also used by action default
include('function.assingfiles.php');

$templatename = '';
if( isset( $params['template'] ) )	$templatename = $params['template'];
// TEMPORARY : I ASSUME THE DEFAULT ACTION WILL BE THE LIST ACTION
if( $templatename != '' && $template = $this->GetTemplate('list_'.$templatename) )
{
	// the template exists, we're going to use it
}
else
{
	// no template specified, or template doesn't exist... we get the default one
	$templatename = $this->GetPreference('default_list_template', '');
	$template = $this->GetTemplate($templatename);
}

#Display template
echo $this->ProcessTemplateFromData($template);
?>

==> DownloadManager-1.5.1.zip: DownloadManager/action.selector.php <==
<?php
if (!isset($gCms)) exit;
//var_dump($params);
$this->UpdateAssociationAgregation();
/*
 * PARSING selector
 *
 * Here come everything what has to do with selector,
 * if selector parameter is set the other parameters
 * are omnited
*/

if( empty( $params['selector'] ) )
	echo $this->DisplayErrorPage($id, $params, $returnid, $this->lang('nocategorysel'));

$showheaders = false;

// parsing the category selector
$categoryid  = html_entity_decode( $params['selector'] );

$sql_prefix = 'SELECT file_id FROM '.cms_db_prefix().'module_downloadmanager_files WHERE ';
$sql = $this->GetFileStdWhere().' AND '.$this->selectorToSQL($categoryid); // set the files where

$query = 'SELECT * FROM '.cms_db_prefix().'module_downloadmanager_files
		WHERE '.$sql.' ORDER BY name';

$files_categories = $this->GetFileCategories('file_id IN ('.$sql_prefix.$sql.')');

$dbresult = $db->Execute($query);

// also used by action default
include('function.assingfiles.php');

$templatename = '';
if( isset( $params['template'] ) )	$templatename = $params['template'];
// TEMPORARY : I ASSUME THE DEFAULT ACTION WILL BE THE LIST ACTION
if( $templatename != '' && $template = $this->GetTemplate('list_'.$templatename) )
{
	// the template exists, we're going to use it
}
else
{
	// no template specified, or template doesn't exist... we get the default one
	$templatename = $this->GetPreference('default_list_template', '');
	$template = $this->GetTemplate($templatename);
}

#Display template
echo $this->ProcessTemplateFromData($template);
?>
